@@ -1,8 +1,8 @@
 package pool
 
 import (
+	"github.com/raitonoberu/sptlrx/services/hosted"
 	"math"
-	"sptlrx/services/hosted"
 	"testing"
 )
 
