@@ -3,24 +3,23 @@ package spotify
 import (
 	"strings"
 
-	"sptlrx/lyrics"
-	"sptlrx/player"
-
-	lyricsapi "github.com/raitonoberu/lyricsapi/lyrics"
+	"github.com/raitonoberu/lyricsapi/spotify"
+	"github.com/raitonoberu/sptlrx/lyrics"
+	"github.com/raitonoberu/sptlrx/player"
 )
 
-var ErrInvalidCookie = lyricsapi.ErrInvalidCookie
+var ErrInvalidCookie = spotify.ErrInvalidCookie
 
 func New(cookie string) (*Client, error) {
 	if cookie == "" {
 		return nil, ErrInvalidCookie
 	}
-	return &Client{lyricsapi.NewLyricsApi(cookie)}, nil
+	return &Client{spotify.NewClient(cookie)}, nil
 }
 
 // Client implements both player.Player and lyrics.Provider
 type Client struct {
-	api *lyricsapi.LyricsApi
+	api *spotify.Client
 }
 
 func (c *Client) State() (*player.State, error) {
@@ -41,7 +40,7 @@ func (c *Client) State() (*player.State, error) {
 
 func (c *Client) Lyrics(id, query string) ([]lyrics.Line, error) {
 	var (
-		result *lyricsapi.LyricsResult
+		result []spotify.LyricsLine
 		err    error
 	)
 	if strings.HasPrefix(id, "spotify:") {
@@ -53,12 +52,12 @@ func (c *Client) Lyrics(id, query string) ([]lyrics.Line, error) {
 	if err != nil {
 		return nil, err
 	}
-	if result == nil || len(result.Lyrics.Lines) == 0 {
+	if len(result) == 0 {
 		return nil, nil
 	}
 
-	lines := make([]lyrics.Line, len(result.Lyrics.Lines))
-	for i, l := range result.Lyrics.Lines {
+	lines := make([]lyrics.Line, len(result))
+	for i, l := range result {
 		lines[i] = lyrics.Line(l)
 	}
 	return lines, nil
